@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '2.0_12'; # TRIAL
+$BZ::Client::VERSION = '4.4_001'; # TRIAL
 
-$BZ::Client::VERSION = '2.012';
+$BZ::Client::VERSION = '4.4001';
 use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
 use HTTP::CookieJar;
@@ -160,7 +160,7 @@ sub login {
     $self->log( 'debug', 'BZ::Client::login, going to log in with username and password' );
 
     my $cookies = HTTP::CookieJar->new();
-    my $response = $self->_api_call( 'User.login', \%params, $cookies );
+    my $response = $self->_api_call( 'User.login', \%params, { cookies => $cookies } );
     if ( not defined( $response->{'id'} )
         or $response->{'id'} !~ m/^\d+$/s )
     {
@@ -180,20 +180,20 @@ sub login {
 sub logout {
     my $self    = shift;
     return 1 unless $self->is_logged_in;
-
+    my $response = 1; # if have not cookie or token, return 1
     my $cookies = $self->{'cookies'};
     my $token = $self->{'token'};
     if ($cookies or $token) {
-        # cannot use _api_call() as response from logout is empty
-        my $params = {};
-        $params->{'token'} = $self->{'token'}
+        my %params;
+        $params{'token'} = $self->{'token'}
             if $self->{'token'};
-        $self->xmlrpc->request( 'methodName' => 'User.logout', params => [$params] );
+        # Note: A good response from User.logout is empty so, empty_response_ok => 1
+        $response = $self->_api_call( 'User.logout', \%params, { empty_response_ok => 1 } );
         $cookies->clear() if $cookies;
         delete $self->{'token'};
         delete $self->{'cookies'};
     }
-    return 1
+    return $response
 }
 
 sub is_logged_in {
@@ -205,20 +205,22 @@ sub is_logged_in {
 }
 
 sub api_call {
-    my ( $self, $methodName, $params ) = @_;
 
-    $params ||= {};
+    my ( $self, $methodName, $params, $options ) = @_;
+
+    $params  ||= {};
+    $options ||= {};
 
     if ( $self->autologin && not $self->is_logged_in() ) {
         $self->login();
     }
 
-    return $self->_api_call( $methodName, $params )
+    return $self->_api_call( $methodName, $params, $options )
 }
 
 sub _api_call {
 
-    my ( $self, $methodName, $params, $cookies ) = @_;
+    my ( $self, $methodName, $params, $options ) = @_;
 
     $self->log( 'debug',
         "BZ::Client::_api_call, sending request for method $methodName to "
@@ -226,8 +228,8 @@ sub _api_call {
 
     my $xmlrpc = $self->xmlrpc();
 
-    if ($cookies) {
-        $xmlrpc->web_agent->{cookie_jar} = $cookies;
+    if ($options->{cookies}) {
+        $xmlrpc->web_agent->{cookie_jar} = $options->{cookies};
     }
 
     $params->{Bugzilla_token} = $self->{'token'}
@@ -243,16 +245,38 @@ sub _api_call {
     my $response =
       $xmlrpc->request( 'methodName' => $methodName, params => [$params] );
 
-    if ( not $response ) {
-        $self->error('Empty response from server.');
+    if ($options->{empty_response_ok}) {
+
+        if ( ref $response and ref($response) ne 'HASH' ) {
+            $self->error("Invalid response from server: $response");
+        }
+
+        if ($response) {
+            $self->log( 'debug',
+                "BZ::Client::_api_call, got response for method $methodName" );
+        }
+        else {
+            $self->log( 'debug',
+                "BZ::Client::_api_call, got empty response for method $methodName but thats OK" );
+            $response = 1
+        }
+
+    }
+    else {
+
+        if ( not $response ) {
+            $self->error('Empty response from server.');
+        }
+
+        if ( ref($response) ne 'HASH' ) {
+            $self->error("Invalid response from server: $response");
+        }
+
+        $self->log( 'debug',
+            "BZ::Client::_api_call, got response for method $methodName" );
+
     }
 
-    if ( ref($response) ne 'HASH' ) {
-        $self->error("Invalid response from server: $response");
-    }
-
-    $self->log( 'debug',
-        "BZ::Client::_api_call, got response for method $methodName" );
 
     return $response
 }
@@ -271,7 +295,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 2.0_12
+version 4.4_001
 
 =head1 SYNOPSIS
 
@@ -281,15 +305,17 @@ version 2.0_12
                                 autologin => 0 );
   $client->login();
 
-=head1 WARNING
+=head1 BUGZILLA VERSIONS
 
-USE THIS 2.0 DEVELOPMENT VERSION AT YOUR OWN RISK!
+Please note that this L<BZ::Client> module is aimed at the XMLRPC API available in Bugzilla 5.0 and earlier.
 
-(Which is actually, a clause in the open source license this software is provided under)
+For 5.1 and later, which have a totally different REST API, please see L<Net::Bugzilla>.
 
-THE API IS CHANGING, STUFF IS BREAKING, YMMV!
+As such, I welcome all patches (via pull request) for functionality relating to 5.0 and earlier.
 
-USE THE 1.x SERIES UNLESS YOU PREFER DEBUGGING TO GETTING THINGS DONE.
+I will only actively hunt down bugs relating to the 'maintained' Bugzilla server softwares. Please upgrade
+your server and duplicate the problem, or see the above commitment to accept patches to fix for older
+versions.
 
 =head1 CLASS METHODS
 
@@ -397,6 +423,21 @@ A boolean that indicates whether to validate the SSL certificate of an
 
 =back
 
+=head3 Connect Via Socks Proxy
+
+Try something like:
+
+ use HTTP::Tiny; # load this manually
+ use IO::Socket::Socks::Wrapper (
+  'HTTP::Tiny::Handle::connect()' => {
+    ProxyAddr    => 'localhost',
+    ProxyPort    => 1080,
+    SocksVersion => 4,
+    Timeout      => 15
+    }
+  );
+  use BZ::Client ...etc
+
 =head1 INSTANCE METHODS
 
 This section lists the methods, which an instance of BZ::Client can
@@ -471,11 +512,33 @@ Sends log messages to whatever is loaded via L</logger>.
 
 =head2 api_call
 
- $response = $client->api_call( $methodName, $params );
+ $response = $client->api_call( $methodName, $params, $options );
 
 Used by subclasses of L<BZ::Client::API> to invoke methods of the Bugzilla
-API. Takes a method name and a hash ref of parameters as input. Returns a
-hash ref of named result objects.
+API. The method name and the hash ref of parameters are sent to the Bugzilla server.
+The options hash ref adjusts the behaviour of this function when calls are made.
+
+The params and options hash refs are optional, although certain param values may be required
+depending on the method name being called. This client library relies upon the Bugzilla
+server to enforce any method parameter requirements, so insufficient requests will still be
+sent to the server for it to then reject them.
+
+Returns a hash ref of named result objects.
+
+=head3 Options
+
+=over 4
+
+=item empty_response_ok
+
+With this set, an empty response is not considered an error. In this case, api_call returns 1 to indicate
+success.
+
+=item cookies
+
+This is used internally to set cookies with the log in functions. Don't touch this.
+
+=back
 
 =head1 ERROR CODES
 
