@@ -6,12 +6,12 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::API;
-$BZ::Client::API::VERSION = '2.0_12'; # TRIAL
+$BZ::Client::API::VERSION = '4.4_001'; # TRIAL
 
-$BZ::Client::API::VERSION = '2.012';
+$BZ::Client::API::VERSION = '4.4001';
 sub api_call {
-    my(undef, $client, $methodName, $params) = @_;
-    return $client->api_call($methodName, $params)
+    my(undef, $client, $methodName, $params, $options) = @_;
+    return $client->api_call($methodName, $params, $options)
 }
 
 sub error {
@@ -71,7 +71,7 @@ BZ::Client::API - Abstract base class for the clients of the Bugzilla API.
 
 =head1 VERSION
 
-version 2.0_12
+version 4.4_001
 
 =head1 SYNOPSIS
 
