@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_12'; # TRIAL
+$BZ::Client::Bug::VERSION = '4.4_001'; # TRIAL
 
-$BZ::Client::Bug::VERSION = '2.012';
+$BZ::Client::Bug::VERSION = '4.4001';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -288,7 +288,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_12
+version 4.4_001
 
 =head1 SYNOPSIS
 
@@ -681,6 +681,29 @@ FIXME
 
 Searches for bugs matching the given parameters.
 
+=head3 Parameters
+
+This is just a quick example, there are lot's of fields
+
+ %params = (
+   'alias' => 'ACONVENIENTALIAS',
+
+   'assigned_to' => 'hopefullynotme@domain.local',
+
+   'creator' => 'littlejohnnytables@school.local',
+
+   'severity' => 'major',
+
+   'status' => 'OPEN',
+
+ );
+
+Criteria are joined in a logical AND. That is, you will be returned bugs that match all of the criteria, not bugs that match any of the criteria.
+
+See also L<https://bugzilla.readthedocs.io/en/5.0/api/core/v1/bug.html#search-bugs>
+
+=head3 Returns
+
 Returns an array or arrayref of bug instance objects with the given ID's.
 
 See L<INSTANCE METHODS> for how to use them.
