@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::User;
-$BZ::Client::User::VERSION = '2.0_12'; # TRIAL
+$BZ::Client::User::VERSION = '4.4_001'; # TRIAL
 
-$BZ::Client::User::VERSION = '2.012';
+$BZ::Client::User::VERSION = '4.4001';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/User.html
@@ -21,7 +21,7 @@ sub offer_account_by_email {
         $params = { email => $params }
     }
     $client->log('debug', $class . '::offer_account_by_email: Inviting');
-    return $class->api_call($client, 'User.offer_account_by_email', $params);
+    return $class->api_call($client, 'User.offer_account_by_email', $params, { empty_response_ok => 1});
 }
 
 sub get {
@@ -83,7 +83,7 @@ BZ::Client::User - Creates and edits user accounts in Bugzilla
 
 =head1 VERSION
 
-version 2.0_12
+version 4.4_001
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ servers installation.
                                 user     => $user,
                                 password => $password );
 
-  my $ok    = BZ::Client::User->offer_account_by_email( $client, 'email@adress' );
+  my $ok    = BZ::Client::User->offer_account_by_email( $client, 'email@address' );
   my $users = BZ::Client::User->get( $client, \%params );
   my $id    = BZ::Client::User->create( $client, \%params );
   my $users = BZ::Client::User->update( $client, \%params );
@@ -132,6 +132,10 @@ nothing if successful
 
 =over 4
 
+=item 50 - Email parameter missing
+
+The email parameter was not provided.
+
 =item 500 - Account Already Exists
 
 An account with that email address already exists in Bugzilla.
@@ -156,7 +160,7 @@ Added in Bugzilla 3.4
 
 Note: At least one of L</ids>, L</names>, or L</match> must be specified.
 
-Note: Users will not be returned more than once, so even if a user is matched by more than one argument, only one user will be returned.
+Note: Users will only appear once in the returned list, even if that user is matched by more than one search argument.
 
 In addition to the parameters below, this method also accepts the standard L<BZ::Client::Bug/include_fields> and L<BZ::Client::Bug/exclude_fields> arguments.
 
