@@ -6,9 +6,9 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC::Value;
-$BZ::Client::XMLRPC::Value::VERSION = '2.0_12'; # TRIAL
+$BZ::Client::XMLRPC::Value::VERSION = '4.4_001'; # TRIAL
 
-$BZ::Client::XMLRPC::Value::VERSION = '2.012';use parent qw( BZ::Client::XMLRPC::Handler );
+$BZ::Client::XMLRPC::Value::VERSION = '4.4001';use parent qw( BZ::Client::XMLRPC::Handler );
 use BZ::Client::XMLRPC::Struct;
 use BZ::Client::XMLRPC::Array;
 use DateTime::Format::ISO8601 ();
@@ -92,7 +92,7 @@ sub end {
                     $val = "$1-$2-$3$4";
                 }
                 $self->{'result'} =
-                  DateTime::Format::ISO8601->parse_datetime($val);
+                  DateTime::Format::ISO8601->parse_datetime($val)->set_time_zone('UTC');
             }
         }
     }
@@ -137,7 +137,7 @@ BZ::Client::XMLRPC::Value - Event handler for parsing a single XML-RPC value.
 
 =head1 VERSION
 
-version 2.0_12
+version 4.4_001
 
 =head1 AUTHORS
 
